==> nextcloud-20.0.12.tgz: nextcloud/apps/user_status/l10n/hu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Legutóbbi állapotok",
    "In a meeting" : "Találkozón",
    "Commuting" : "Ingázás",
    "Out sick" : "Beteg szabadság",
    "Vacationing" : "Nyaralás",
    "Working remotely" : "Távoli munkavégzés",
    "User status" : "Felhasználói állapot",
    "Clear status message after" : "Állapotüzenet törlése ennyi idő után:",
    "What's your status?" : "Mi az állapota?",
    "Set status" : "Állapot beállítása",
    "Online status" : "Online állapot",
    "Status message" : "Állapotüzenet",
    "Clear status message" : "Állapotüzenet törlése",
    "Set status message" : "Állapotüzenet beállítása",
    "There was an error saving the status" : "Hiba történt az állapot mentésekor",
    "There was an error clearing the status" : "Hiba történt az állapot törlésekor",
    "No recent status changes" : "Nincsenek legutóbbi állapotváltozások",
    "Away" : "Távol",
    "Do not disturb" : "Ne zavarjanak",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ne törölje",
    "Today" : "Ma",
    "This week" : "Ez a hét",
    "Online" : "Online",
    "Invisible" : "Láthatatlan",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Hiba történt az új állapot mentésekor",
    "30 minutes" : "30 perc",
    "1 hour" : "1 óra",
    "4 hours" : "4 óra",
    "Mute all notifications" : "Összes értesítés némítása",
    "Appear offline" : "Offline módon jelenik meg",
    "Clear status after" : "Állapot törlése ennyi idő után"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/user_status/l10n/hu.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Legutóbbi állapotok",
    "In a meeting" : "Találkozón",
    "Commuting" : "Ingázás",
    "Out sick" : "Beteg szabadság",
    "Vacationing" : "Nyaralás",
    "Working remotely" : "Távoli munkavégzés",
    "User status" : "Felhasználói állapot",
    "Clear status message after" : "Állapotüzenet törlése ennyi idő után:",
    "Set status" : "Állapot beállítása",
    "Online status" : "Online állapot",
    "Status message" : "Állapotüzenet",
    "Clear status message" : "Állapotüzenet törlése",
    "Set status message" : "Állapotüzenet beállítása",
    "There was an error saving the status" : "Hiba történt az állapot mentésekor",
    "There was an error clearing the status" : "Hiba történt az állapot törlésekor",
    "No recent status changes" : "Nincsenek legutóbbi állapotváltozások",
    "Away" : "Távol",
    "Do not disturb" : "Ne zavarjanak",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Ne törölje",
    "Today" : "Ma",
    "This week" : "Ez a hét",
    "Online" : "Online",
    "Invisible" : "Láthatatlan",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Hiba történt az új állapot mentésekor",
    "30 minutes" : "30 perc",
    "1 hour" : "1 óra",
    "4 hours" : "4 óra",
    "Mute all notifications" : "Összes értesítés némítása",
    "Appear offline" : "Offline módon jelenik meg",
    "Clear status after" : "Állapot törlése ennyi idő után",
    "What's your status?" : "Mi az állapota?"
},
"nplurals=2; plural=(n != 1);");
